diff --git a/README.md b/README.md
index 4c41e227f..f14bdfad8 100644
--- a/README.md
+++ b/README.md
@@ -66,6 +66,10 @@ Homepage is highly customizable, with support for custom themes, custom CSS & JS
For configuration options, examples and more, [please check out the homepage documentation](http://gethomepage.dev).
+## Security Notice 🔒
+
+Please note that when using features such as widgets, Homepage can access personal information (for example from your home automation system) and Homepage currently does not (and is not planned to) include any authentication layer itself. Thus, we recommend homepage be deployed behind a reverse proxy including authentication, SSL etc, and / or behind a VPN.
+
## With Docker
Using docker compose:
diff --git a/docs/configs/kubernetes.md b/docs/configs/kubernetes.md
index 6ba995c49..c76813f47 100644
--- a/docs/configs/kubernetes.md
+++ b/docs/configs/kubernetes.md
@@ -98,6 +98,8 @@ When the Kubernetes cluster connection has been properly configured, this servic
If you are using multiple instances of homepage, an `instance` annotation can be specified to limit services to a specific instance. If no instance is provided, the service will be visible on all instances.
+If you have a single service that needs to be shown on multiple specific instances of homepage (but not on all of them), the service can be annotated by multiple `instance.name` annotations, where `name` can be the names of your specific multiple homepage instances. For example, a service that is annotated with `gethomepage.dev/instance.public: ""` and `gethomepage.dev/instance.internal: ""` will be shown on `public` and `internal` homepage instances.
+
### Traefik IngressRoute support
Homepage can also read ingresses defined using the Traefik IngressRoute custom resource definition. Due to the complex nature of Traefik routing rules, it is required for the `gethomepage.dev/href` annotation to be set:
diff --git a/docs/installation/index.md b/docs/installation/index.md
index f1d317c45..beb370c11 100644
--- a/docs/installation/index.md
+++ b/docs/installation/index.md
@@ -7,6 +7,10 @@ description: Docs intro
You have a few options for deploying homepage, depending on your needs. We offer docker images for a majority of platforms. You can also install and run homepage from source if Docker is not your thing. It can even be installed on Kubernetes with Helm.
+!!! danger
+
+ Please note that when using features such as widgets, Homepage can access personal information (for example from your home automation system) and Homepage currently does not (and is not planned to) include any authentication layer itself. Thus, we recommend homepage be deployed behind a reverse proxy including authentication, SSL etc, and / or behind a VPN.
+
diff --git a/docs/widgets/services/mjpeg.md b/docs/widgets/services/mjpeg.md
index e0e912d03..b0784ff0d 100644
--- a/docs/widgets/services/mjpeg.md
+++ b/docs/widgets/services/mjpeg.md
@@ -3,7 +3,7 @@ title: MJPEG
description: MJPEG Stream Widget Configuration
---
-![camera-preview](https://github.com/gethomepage/homepage-docs/assets/82196/dc375ae3-0670-489f-8db6-83ff1f423d12)
+![camera-preview](https://github.com/gethomepage/homepage/assets/4887959/dbc388d7-04a6-482c-8f36-f9534689b062)
Pass the stream URL from a service like [µStreamer](https://github.com/pikvm/ustreamer) or [camera-streamer](https://github.com/ayufan/camera-streamer).
diff --git a/public/locales/af/common.json b/public/locales/af/common.json
index 1aab2d89d..7884acdd9 100644
--- a/public/locales/af/common.json
+++ b/public/locales/af/common.json
@@ -876,5 +876,17 @@
"crowdsec": {
"alerts": "Waarskuwings",
"bans": "Verbanne"
+ },
+ "wgeasy": {
+ "connected": "Gekoppel",
+ "enabled": "Geaktiveer",
+ "disabled": "Onaktief",
+ "total": "Totaal"
+ },
+ "swagdashboard": {
+ "proxied": "Proxied",
+ "auth": "With Auth",
+ "outdated": "Outdated",
+ "banned": "Banned"
}
}
diff --git a/public/locales/ar/common.json b/public/locales/ar/common.json
index b66a97a81..3bb2acfcd 100644
--- a/public/locales/ar/common.json
+++ b/public/locales/ar/common.json
@@ -876,5 +876,17 @@
"crowdsec": {
"alerts": "تنبيهات",
"bans": "Bans"
+ },
+ "wgeasy": {
+ "connected": "Connected",
+ "enabled": "مفعل",
+ "disabled": "معطل",
+ "total": "المجموع"
+ },
+ "swagdashboard": {
+ "proxied": "Proxied",
+ "auth": "With Auth",
+ "outdated": "Outdated",
+ "banned": "Banned"
}
}
diff --git a/public/locales/bg/common.json b/public/locales/bg/common.json
index 0d232fc11..443c28b8b 100644
--- a/public/locales/bg/common.json
+++ b/public/locales/bg/common.json
@@ -876,5 +876,17 @@
"crowdsec": {
"alerts": "Предупреждения",
"bans": "Bans"
+ },
+ "wgeasy": {
+ "connected": "Connected",
+ "enabled": "Активирано",
+ "disabled": "Деактивирано",
+ "total": "Общо"
+ },
+ "swagdashboard": {
+ "proxied": "Proxied",
+ "auth": "With Auth",
+ "outdated": "Outdated",
+ "banned": "Banned"
}
}
diff --git a/public/locales/ca/common.json b/public/locales/ca/common.json
index a431f9a4e..78a32c0db 100644
--- a/public/locales/ca/common.json
+++ b/public/locales/ca/common.json
@@ -876,5 +876,17 @@
"crowdsec": {
"alerts": "Alertes",
"bans": "Prohibicions"
+ },
+ "wgeasy": {
+ "connected": "Connectat",
+ "enabled": "Activat",
+ "disabled": "Desactivat",
+ "total": "Total"
+ },
+ "swagdashboard": {
+ "proxied": "Proxied",
+ "auth": "With Auth",
+ "outdated": "Outdated",
+ "banned": "Banned"
}
}
diff --git a/public/locales/cs/common.json b/public/locales/cs/common.json
index f1540dd73..48030d627 100644
--- a/public/locales/cs/common.json
+++ b/public/locales/cs/common.json
@@ -876,5 +876,17 @@
"crowdsec": {
"alerts": "Upozornění",
"bans": "Bans"
+ },
+ "wgeasy": {
+ "connected": "Connected",
+ "enabled": "Povoleno",
+ "disabled": "Zakázáno",
+ "total": "Celkem"
+ },
+ "swagdashboard": {
+ "proxied": "Proxied",
+ "auth": "With Auth",
+ "outdated": "Outdated",
+ "banned": "Banned"
}
}
diff --git a/public/locales/da/common.json b/public/locales/da/common.json
index 661032bc7..e4c2e0a9f 100644
--- a/public/locales/da/common.json
+++ b/public/locales/da/common.json
@@ -876,5 +876,17 @@
"crowdsec": {
"alerts": "Advarsler",
"bans": "Bans"
+ },
+ "wgeasy": {
+ "connected": "Connected",
+ "enabled": "Aktiveret",
+ "disabled": "Deaktiveret",
+ "total": "Total"
+ },
+ "swagdashboard": {
+ "proxied": "Proxied",
+ "auth": "With Auth",
+ "outdated": "Outdated",
+ "banned": "Banned"
}
}
diff --git a/public/locales/de/common.json b/public/locales/de/common.json
index a2cafb841..4a188956e 100644
--- a/public/locales/de/common.json
+++ b/public/locales/de/common.json
@@ -876,5 +876,17 @@
"crowdsec": {
"alerts": "Warnungen",
"bans": "Banns"
+ },
+ "wgeasy": {
+ "connected": "Verbunden",
+ "enabled": "Aktiviert",
+ "disabled": "Deaktiviert",
+ "total": "Gesamt"
+ },
+ "swagdashboard": {
+ "proxied": "Proxied",
+ "auth": "Mit Auth",
+ "outdated": "Veraltet",
+ "banned": "Gebannt"
}
}
diff --git a/public/locales/el/common.json b/public/locales/el/common.json
index dfa0a5bc9..2ffcd5221 100644
--- a/public/locales/el/common.json
+++ b/public/locales/el/common.json
@@ -40,14 +40,14 @@
},
"resources": {
"cpu": "Επεξεργαστής",
- "mem": "MEM",
+ "mem": "Μνήμη",
"total": "Σύνολο",
"free": "Δωρεάν",
"used": "χρησιμοποιημένο",
"load": "Φόρτωση",
- "temp": "ΘΕΡΜΟΚΡΑΣΪΑ",
+ "temp": "Θερμοκρασία",
"max": "Μέγιστο",
- "uptime": "ΠΑΝΩ"
+ "uptime": "Χρόνος Λειτουργίας"
},
"unifi": {
"users": "Χρήστες",
@@ -61,7 +61,7 @@
"wlan_devices": "WLAN Συσκευές",
"lan_users": "LAN Χρήστες",
"wlan_users": "WLAN Χρήστες",
- "up": "ΠΑΝΩ",
+ "up": "Χρόνος Λειτουργίας",
"down": "ΚΑΤΩ",
"wait": "Παρακαλώ περιμένετε",
"empty_data": "Άγνωστη κατάσταση υποσυστήματος"
@@ -69,7 +69,7 @@
"docker": {
"rx": "RX",
"tx": "TX",
- "mem": "MEM",
+ "mem": "Μνήμη",
"cpu": "Επεξεργαστής",
"running": "Τρέχων",
"offline": "Εκτός σύνδεσης",
@@ -85,16 +85,16 @@
"ping": {
"error": "Σφάλμα",
"ping": "Ping",
- "down": "Down",
- "up": "Up",
+ "down": "Ping down",
+ "up": "Ping up",
"not_available": "Μη διαθέσιμο"
},
"siteMonitor": {
"http_status": "Κατάσταση HTTP",
"error": "Σφάλμα",
"response": "Απόκριση",
- "down": "Down",
- "up": "Up",
+ "down": "Ping down",
+ "up": "Ping up",
"not_available": "Μη διαθέσιμο"
},
"emby": {
@@ -136,16 +136,16 @@
"connectionStatus": "Κατάσταση",
"connectionStatusUnconfigured": "Μη Ρυθμισμένο",
"connectionStatusConnecting": "Κατάσταση Σύνδεσης",
- "connectionStatusAuthenticating": "Authenticating",
- "connectionStatusPendingDisconnect": "Pending Disconnect",
- "connectionStatusDisconnecting": "Disconnecting",
- "connectionStatusDisconnected": "Disconnected",
- "connectionStatusConnected": "Connected",
+ "connectionStatusAuthenticating": "Ταυτοποίηση",
+ "connectionStatusPendingDisconnect": "Εκκρεμεί Αποσύνδεση",
+ "connectionStatusDisconnecting": "Αποσύνδεση",
+ "connectionStatusDisconnected": "Αποσυνδέθηκε",
+ "connectionStatusConnected": "Συνδέθηκε",
"uptime": "Χρόνος Λειτουργίας",
- "maxDown": "Max. Down",
- "maxUp": "Max. Up",
- "down": "Down",
- "up": "Up",
+ "maxDown": "Μέγιστο Download",
+ "maxUp": "Μέγιστο Upload",
+ "down": "Ping down",
+ "up": "Ping up",
"received": "Ληφθέντα",
"sent": "Απεσταλμένα",
"externalIPAddress": "Εξωτερική IP"
@@ -217,7 +217,7 @@
"memUsage": "Χρήση μνήμης",
"systemTempC": "Θερμοκρασία συστήματος",
"poolUsage": "Χρήση πισίνας",
- "volumeUsage": "Volume Usage",
+ "volumeUsage": "Χρήση Όγκου",
"invalid": "Μη έγκυρο"
},
"deluge": {
@@ -273,15 +273,15 @@
},
"overseerr": {
"pending": "Σε εκκρεμότητα",
- "processing": "Processing",
+ "processing": "Σε επεξεργασία",
"approved": "Εγκρίθηκε",
"available": "Διαθέσιμο"
},
"netalertx": {
"total": "Σύνολο",
- "connected": "Connected",
- "new_devices": "New Devices",
- "down_alerts": "Down Alerts"
+ "connected": "Συνδέθηκε",
+ "new_devices": "Νέες συσκευές",
+ "down_alerts": "Ειδοποιήσεις offline"
},
"pihole": {
"queries": "Queries",
@@ -309,26 +309,26 @@
"address": "Διεύθυνση",
"expires": "Λήγει",
"never": "Ποτέ",
- "last_seen": "Last Seen",
+ "last_seen": "Τελευταία Σύνδεση",
"now": "Τώρα",
- "years": "{{number}}y",
- "weeks": "{{number}}w",
- "days": "{{number}}d",
- "hours": "{{number}}h",
- "minutes": "{{number}}m",
- "seconds": "{{number}}s",
+ "years": "{{number}}χρόνια",
+ "weeks": "{{number}}εβδομάδες",
+ "days": "{{number}}μέρες",
+ "hours": "{{number}}ώρες",
+ "minutes": "{{number}}λεπτά",
+ "seconds": "{{number}}δευτερόλεπτα",
"ago": "{{value}} πρίν"
},
"tdarr": {
"queue": "Ουρά",
- "processed": "Processed",
- "errored": "Errored",
- "saved": "Saved"
+ "processed": "Σε επεξεργασία",
+ "errored": "Σφάλματα",
+ "saved": "Αποθηκεύτηκε"
},
"traefik": {
- "routers": "Routers",
+ "routers": "Δρομολογητές",
"services": "Υπηρεσίες",
- "middleware": "Middleware"
+ "middleware": "Ενδιάμεσο λογισμικό"
},
"navidrome": {
"nothing_streaming": "Δεν υπάρχουν ενεργές ροές",
@@ -360,7 +360,7 @@
},
"jackett": {
"configured": "Ρυθμισμένο",
- "errored": "Errored"
+ "errored": "Σφάλματα"
},
"strelaysrv": {
"numActiveSessions": "Συνεδρίες",
@@ -371,7 +371,7 @@
"mastodon": {
"user_count": "Χρήστες",
"status_count": "Δημοσιεύσεις",
- "domain_count": "Domains"
+ "domain_count": "Τομείς"
},
"medusa": {
"wanted": "Επιθυμούντε",
@@ -386,7 +386,7 @@
"down": "Εκτός σύνδεσης"
},
"miniflux": {
- "read": "Read",
+ "read": "Διαβάστηκε",
"unread": "Μη Διαβασμένο"
},
"authentik": {
@@ -395,7 +395,7 @@
"failedLoginsLast24H": "Αποτυχημένες Συνδέσεις (24h)"
},
"proxmox": {
- "mem": "MEM",
+ "mem": "Μνήμη",
"cpu": "Επεξεργαστής",
"lxc": "LXC",
"vms": "VMs"
@@ -404,17 +404,17 @@
"cpu": "Επεξεργαστής",
"load": "Φόρτωση",
"wait": "Παρακαλώ περιμένετε",
- "temp": "ΘΕΡΜΟΚΡΑΣΪΑ",
+ "temp": "Θερμοκρασία",
"_temp": "Temp",
"warn": "Warn",
- "uptime": "ΠΑΝΩ",
+ "uptime": "Χρόνος Λειτουργίας",
"total": "Σύνολο",
"free": "Δωρεάν",
"used": "χρησιμοποιημένο",
"days": "d",
"hours": "h",
"crit": "Crit",
- "read": "Read",
+ "read": "Διαβάστηκε",
"write": "Write",
"gpu": "GPU",
"mem": "Μνήμη",
@@ -450,80 +450,80 @@
"55-night": "Heavy Drizzle",
"56-day": "Light Freezing Drizzle",
"56-night": "Light Freezing Drizzle",
- "57-day": "Freezing Drizzle",
- "57-night": "Freezing Drizzle",
- "61-day": "Light Rain",
- "61-night": "Light Rain",
- "63-day": "Rain",
- "63-night": "Rain",
- "65-day": "Heavy Rain",
- "65-night": "Heavy Rain",
- "66-day": "Freezing Rain",
- "66-night": "Freezing Rain",
- "67-day": "Freezing Rain",
- "67-night": "Freezing Rain",
- "71-day": "Light Snow",
- "71-night": "Light Snow",
- "73-day": "Snow",
- "73-night": "Snow",
- "75-day": "Heavy Snow",
- "75-night": "Heavy Snow",
- "77-day": "Snow Grains",
- "77-night": "Snow Grains",
- "80-day": "Light Showers",
- "80-night": "Light Showers",
- "81-day": "Showers",
- "81-night": "Showers",
- "82-day": "Heavy Showers",
- "82-night": "Heavy Showers",
- "85-day": "Snow Showers",
- "85-night": "Snow Showers",
- "86-day": "Snow Showers",
- "86-night": "Snow Showers",
- "95-day": "Thunderstorm",
- "95-night": "Thunderstorm",
- "96-day": "Thunderstorm With Hail",
- "96-night": "Thunderstorm With Hail",
- "99-day": "Thunderstorm With Hail",
- "99-night": "Thunderstorm With Hail"
+ "57-day": "Παγωμένο ψιχάλισμα",
+ "57-night": "Παγωμένο ψιχάλισμα",
+ "61-day": "Ψιλόβροχο",
+ "61-night": "Ψιλόβροχο",
+ "63-day": "Βροχή",
+ "63-night": "Βροχή",
+ "65-day": "Δυνατή βροχή",
+ "65-night": "Δυνατή βροχή",
+ "66-day": "Παγωμένη βροχή",
+ "66-night": "Παγωμένη βροχή",
+ "67-day": "Παγωμένη βροχή",
+ "67-night": "Παγωμένη βροχή",
+ "71-day": "Ελαφριά Χιονόπτωση",
+ "71-night": "Ελαφριά Χιονόπτωση",
+ "73-day": "Χιόνι",
+ "73-night": "Χιόνι",
+ "75-day": "Ισχυρή χιονόπτωση",
+ "75-night": "Ισχυρή χιονόπτωση",
+ "77-day": "Κόκκοι Χιονιού",
+ "77-night": "Κόκκοι Χιονιού",
+ "80-day": "Ασθενείς βροχές",
+ "80-night": "Ασθενείς βροχές",
+ "81-day": "Βροχοπτώσεις",
+ "81-night": "Βροχοπτώσεις",
+ "82-day": "Ισχυρές βροχοπτώσεις",
+ "82-night": "Ισχυρές βροχοπτώσεις",
+ "85-day": "Χιονοπτώσεις",
+ "85-night": "Χιονοπτώσεις",
+ "86-day": "Χιονοπτώσεις",
+ "86-night": "Χιονοπτώσεις",
+ "95-day": "Καταιγίδα",
+ "95-night": "Καταιγίδα",
+ "96-day": "Καταιγίδα Με Χαλάζι",
+ "96-night": "Καταιγίδα Με Χαλάζι",
+ "99-day": "Καταιγίδα Με Χαλάζι",
+ "99-night": "Καταιγίδα Με Χαλάζι"
},
"homebridge": {
- "available_update": "System",
- "updates": "Updates",
- "update_available": "Update Available",
- "up_to_date": "Up to Date",
+ "available_update": "Σύστημα",
+ "updates": "Ενημερώσεις",
+ "update_available": "Διαθέσιμη ενημέρωση",
+ "up_to_date": "Ενημερωμένο",
"child_bridges": "Child Bridges",
"child_bridges_status": "{{ok}}/{{total}}",
- "up": "Up",
+ "up": "Ping up",
"pending": "Σε εκκρεμότητα",
- "down": "Down"
+ "down": "Ping down"
},
"healthchecks": {
"new": "New",
- "up": "Up",
+ "up": "Ping up",
"grace": "In Grace Period",
- "down": "Down",
+ "down": "Ping down",
"paused": "Paused",
"status": "Κατάσταση",
- "last_ping": "Last Ping",
- "never": "No pings yet"
+ "last_ping": "Τελευταίο Ping",
+ "never": "Δεν υπάρχουν ping ακόμα"
},
"watchtower": {
- "containers_scanned": "Scanned",
- "containers_updated": "Updated",
- "containers_failed": "Failed"
+ "containers_scanned": "Σκαναρισμένο",
+ "containers_updated": "Ενημερώθηκε",
+ "containers_failed": "Απέτυχε"
},
"autobrr": {
"approvedPushes": "Εγκρίθηκε",
- "rejectedPushes": "Rejected",
- "filters": "Filters",
+ "rejectedPushes": "Απορρίφθηκε",
+ "filters": "Φίλτρα",
"indexers": "Ευρετήρια"
},
"tubearchivist": {
"downloads": "Ουρά",
- "videos": "Videos",
+ "videos": "Βίντεο",
"channels": "Κανάλια",
- "playlists": "Playlists"
+ "playlists": "Λίστες αναπαραγωγής"
},
"truenas": {
"load": "Φόρτος Συστήματος",
@@ -544,18 +544,18 @@
"hdhomerun": {
"channels": "Κανάλια",
"hd": "HD",
- "tunerCount": "Tuners",
+ "tunerCount": "Δέκτες",
"channelNumber": "Κανάλι",
"channelNetwork": "Δίκτυο",
- "signalStrength": "Strength",
+ "signalStrength": "Ισχύς σήματος",
"signalQuality": "Ποιότητα",
"symbolQuality": "Ποιότητα",
"networkRate": "Ρυθμός bit",
- "clientIP": "Client"
+ "clientIP": "Πελάτης"
},
"scrutiny": {
"passed": "Passed",
- "failed": "Failed",
+ "failed": "Απέτυχε",
"unknown": "Άγνωστο"
},
"paperlessngx": {
@@ -617,8 +617,8 @@
"load": "Load Avg",
"memory": "Mem Usage",
"wanStatus": "WAN Status",
- "up": "Up",
- "down": "Down",
+ "up": "Ping up",
+ "down": "Ping down",
"temp": "Temp",
"disk": "Χρήση δίσκου",
"wanIP": "WAN IP"
@@ -632,14 +632,14 @@
"immich": {
"users": "Χρήστες",
"photos": "Φωτογραφίες",
- "videos": "Videos",
- "storage": "Storage"
+ "videos": "Βίντεο",
+ "storage": "Αποθηκευτικός χώρος"
},
"uptimekuma": {
- "up": "Sites Up",
- "down": "Sites Down",
+ "up": "Online τοποθεσίες",
+ "down": "Offline τοποθεσίες",
"uptime": "Χρόνος Λειτουργίας",
- "incident": "Incident",
+ "incident": "Περιστατικό",
"m": "m"
},
"atsumeru": {
@@ -666,100 +666,100 @@
"photoprism": {
"albums": "Άλμπουμ",
"photos": "Φωτογραφίες",
- "videos": "Videos",
- "people": "People"
+ "videos": "Βίντεο",
+ "people": "Άνθρωποι"
},
"fileflows": {
"queue": "Ουρά",
- "processing": "Processing",
- "processed": "Processed",
- "time": "Time"
+ "processing": "Σε επεξεργασία",
+ "processed": "Σε επεξεργασία",
+ "time": "Ώρα"
},
"grafana": {
- "dashboards": "Dashboards",
- "datasources": "Data Sources",
- "totalalerts": "Total Alerts",
- "alertstriggered": "Alerts Triggered"
+ "dashboards": "Πίνακας Ελέγχου",
+ "datasources": "Πηγές Δεδομένων",
+ "totalalerts": "Σύνολο Ειδοποιήσεων",
+ "alertstriggered": "Ενεργοποιημένες Ειδοποιήσεις"
},
"nextcloud": {
- "cpuload": "Cpu Load",
- "memoryusage": "Memory Usage",
- "freespace": "Free Space",
- "activeusers": "Active Users",
- "numfiles": "Files",
- "numshares": "Shared Items"
+ "cpuload": "Φόρτος CPU",
+ "memoryusage": "Χρήση Mνήμης",
+ "freespace": "Ελεύθερος χώρος",
+ "activeusers": "Ενεργοί χρήστες",
+ "numfiles": "Αρχεία",
+ "numshares": "Κοινόχρηστα στοιχεία"
},
"kopia": {
"status": "Κατάσταση",
- "size": "Size",
- "lastrun": "Last Run",
- "nextrun": "Next Run",
- "failed": "Failed"
+ "size": "Μέγεθος",
+ "lastrun": "Τελευταία εκτέλεση",
+ "nextrun": "Επόμενη εκτέλεση",
+ "failed": "Απέτυχε"
},
"unmanic": {
- "active_workers": "Active Workers",
+ "active_workers": "Ενεργοί χρήστες",
"total_workers": "Total Workers",
- "records_total": "Queue Length"
+ "records_total": "Μήκος Ουράς"
},
"pterodactyl": {
"servers": "Διακομιστές",
- "nodes": "Nodes"
+ "nodes": "Κόμβοι [Nodes]"
},
"prometheus": {
- "targets_up": "Targets Up",
- "targets_down": "Targets Down",
- "targets_total": "Total Targets"
+ "targets_up": "Στόχοι Πάνω",
+ "targets_down": "Στόχοι Κάτω",
+ "targets_total": "Συνολικοί Στόχοι"
},
"gatus": {
- "up": "Sites Up",
- "down": "Sites Down",
+ "up": "Online τοποθεσίες",
+ "down": "Offline τοποθεσίες",
"uptime": "Χρόνος Λειτουργίας"
},
"ghostfolio": {
"gross_percent_today": "Σήμερα",
- "gross_percent_1y": "One year",
- "gross_percent_max": "All time"
+ "gross_percent_1y": "Ένας χρόνος",
+ "gross_percent_max": "Διαχρονικά"
},
"audiobookshelf": {
"podcasts": "Podcasts",
"books": "Βιβλία",
- "podcastsDuration": "Duration",
- "booksDuration": "Duration"
+ "podcastsDuration": "Διάρκεια",
+ "booksDuration": "Διάρκεια"
},
"homeassistant": {
- "people_home": "People Home",
- "lights_on": "Lights On",
- "switches_on": "Switches On"
+ "people_home": "Σύνολο ανθρώπων στο σπίτι",
+ "lights_on": "Αναμμένα φώτα",
+ "switches_on": "Ανοιχτοί διακόπτες"
},
"whatsupdocker": {
- "monitoring": "Monitoring",
- "updates": "Updates"
+ "monitoring": "Παρακολούθηση",
+ "updates": "Ενημερώσεις"
},
"calibreweb": {
"books": "Βιβλία",
- "authors": "Authors",
+ "authors": "Συντάκτες",
"categories": "Κατηγορίες",
"series": "Σειρές"
},
"jdownloader": {
"downloadCount": "Ουρά",
"downloadBytesRemaining": "Υπόλοιπο",
- "downloadTotalBytes": "Size",
+ "downloadTotalBytes": "Μέγεθος",
"downloadSpeed": "Ταχύτητα"
},
"kavita": {
"seriesCount": "Σειρές",
- "totalFiles": "Files"
+ "totalFiles": "Αρχεία"
},
"azuredevops": {
- "result": "Result",
+ "result": "Αποτέλεσμα",
"status": "Κατάσταση",
"buildId": "Build ID",
- "succeeded": "Succeeded",
- "notStarted": "Not Started",
- "failed": "Failed",
- "canceled": "Canceled",
- "inProgress": "In Progress",
+ "succeeded": "Πέτυχε",
+ "notStarted": "Δεν ξεκίνησε",
+ "failed": "Απέτυχε",
+ "canceled": "Ακυρώθηκε",
+ "inProgress": "Σε εξέλιξη",
"totalPrs": "Total PRs",
"myPrs": "My PRs",
"approved": "Εγκρίθηκε"
@@ -768,8 +768,8 @@
"status": "Κατάσταση",
"online": "Συνδεδεμένοι",
"offline": "Εκτός σύνδεσης",
- "name": "Name",
- "map": "Map",
+ "name": "Όνομα",
+ "map": "Χάρτης",
"currentPlayers": "Current players",
"players": "Παίκτες",
"maxPlayers": "Max players",
@@ -777,30 +777,30 @@
"ping": "Ping"
},
"urbackup": {
- "ok": "Ok",
- "errored": "Errors",
- "noRecent": "Out of Date",
- "totalUsed": "Used Storage"
+ "ok": "Οκ",
+ "errored": "Σφάλματα",
+ "noRecent": "Απαρχαιωμένη έκδοση",
+ "totalUsed": "Χώρος αποθήκευσης σε χρήση"
},
"mealie": {
- "recipes": "Recipes",
+ "recipes": "Συνταγές",
"users": "Χρήστες",
"categories": "Κατηγορίες",
- "tags": "Tags"
+ "tags": "Ετικέτες"
},
"openmediavault": {
- "downloading": "Downloading",
+ "downloading": "Γίνεται λήψη",
"total": "Σύνολο",
"running": "Τρέχων",
"stopped": "Σταματημένο",
"passed": "Passed",
- "failed": "Failed"
+ "failed": "Απέτυχε"
},
"openwrt": {
"uptime": "Χρόνος Λειτουργίας",
"cpuLoad": "CPU Load Avg (5m)",
- "up": "Up",
- "down": "Down",
+ "up": "Ping up",
+ "down": "Ping down",
"bytesTx": "Transmitted",
"bytesRx": "Ληφθέντα"
},
@@ -809,13 +809,13 @@
"uptime": "Χρόνος Λειτουργίας",
"lastDown": "Last Downtime",
"downDuration": "Downtime Duration",
- "sitesUp": "Sites Up",
- "sitesDown": "Sites Down",
+ "sitesUp": "Online τοποθεσίες",
+ "sitesDown": "Offline τοποθεσίες",
"paused": "Paused",
"notyetchecked": "Not Yet Checked",
- "up": "Up",
+ "up": "Ping up",
"seemsdown": "Seems Down",
- "down": "Down",
+ "down": "Ping down",
"unknown": "Άγνωστο"
},
"calendar": {
@@ -857,12 +857,12 @@
"performers": "Performers",
"studios": "Studios",
"movies": "Ταινίες",
- "tags": "Tags",
+ "tags": "Ετικέτες",
"oCount": "O Count"
},
"tandoor": {
"users": "Χρήστες",
- "recipes": "Recipes",
+ "recipes": "Συνταγές",
"keywords": "Keywords"
},
"homebox": {
@@ -876,5 +876,17 @@
"crowdsec": {
"alerts": "Ειδοποιήσεις",
"bans": "Bans"
+ },
+ "wgeasy": {
+ "connected": "Συνδέθηκε",
+ "enabled": "Ενεργοποιημένο",
+ "disabled": "Απενεργοποιημένο",
+ "total": "Σύνολο"
+ },
+ "swagdashboard": {
+ "proxied": "Proxied",
+ "auth": "With Auth",
+ "outdated": "Outdated",
+ "banned": "Banned"
}
}
diff --git a/public/locales/eo/common.json b/public/locales/eo/common.json
index 4fa17c473..de28af1ba 100644
--- a/public/locales/eo/common.json
+++ b/public/locales/eo/common.json
@@ -876,5 +876,17 @@
"crowdsec": {
"alerts": "Alerts",
"bans": "Bans"
+ },
+ "wgeasy": {
+ "connected": "Connected",
+ "enabled": "Enabled",
+ "disabled": "Disabled",
+ "total": "Totalo"
+ },
+ "swagdashboard": {
+ "proxied": "Proxied",
+ "auth": "With Auth",
+ "outdated": "Outdated",
+ "banned": "Banned"
}
}
diff --git a/public/locales/es/common.json b/public/locales/es/common.json
index 10aa7c6ce..075a4c566 100644
--- a/public/locales/es/common.json
+++ b/public/locales/es/common.json
@@ -140,7 +140,7 @@
"connectionStatusPendingDisconnect": "Desconexión pendiente",
"connectionStatusDisconnecting": "Desconectando",
"connectionStatusDisconnected": "Desconectado",
- "connectionStatusConnected": "Connected",
+ "connectionStatusConnected": "Conectado",
"uptime": "Tiempo activo",
"maxDown": "Descarga máxima",
"maxUp": "Subida máxima",
@@ -279,9 +279,9 @@
},
"netalertx": {
"total": "Total",
- "connected": "Connected",
- "new_devices": "New Devices",
- "down_alerts": "Down Alerts"
+ "connected": "Conectado",
+ "new_devices": "Nuevos dispositivos",
+ "down_alerts": "Alertas de caída"
},
"pihole": {
"queries": "Consultas",
@@ -544,7 +544,7 @@
"hdhomerun": {
"channels": "Canales",
"hd": "Alta definición",
- "tunerCount": "Tuners",
+ "tunerCount": "Sintonizadores",
"channelNumber": "Canal",
"channelNetwork": "Red",
"signalStrength": "Intensidad",
@@ -827,7 +827,7 @@
},
"romm": {
"platforms": "Plataformas",
- "totalRoms": "Total ROMs"
+ "totalRoms": "ROMs totales"
},
"netdata": {
"warnings": "Advertencias",
@@ -835,38 +835,38 @@
},
"plantit": {
"events": "Eventos",
- "plants": "Plants",
+ "plants": "Plantas",
"photos": "Fotos",
- "species": "Species"
+ "species": "Especies"
},
"gitea": {
"notifications": "Notificaciones",
"issues": "Números",
- "pulls": "Pull Requests"
+ "pulls": "Solicitudes de cambios"
},
"stash": {
- "scenes": "Scenes",
- "scenesPlayed": "Scenes Played",
- "playCount": "Total Plays",
- "playDuration": "Time Watched",
- "sceneSize": "Scenes Size",
- "sceneDuration": "Scenes Duration",
+ "scenes": "Escenas",
+ "scenesPlayed": "Escenas reproducidas",
+ "playCount": "Reproducciones totales",
+ "playDuration": "Tiempo visto",
+ "sceneSize": "Tamaño de las escenas",
+ "sceneDuration": "Duración de las escenas",
"images": "Imágenes",
"imageSize": "Tamaño de imagen",
"galleries": "Galerías",
- "performers": "Performers",
- "studios": "Studios",
+ "performers": "Intérpretes",
+ "studios": "Estudios",
"movies": "Películas",
"tags": "Etiquetas",
- "oCount": "O Count"
+ "oCount": "O cuenta"
},
"tandoor": {
"users": "Usuarios",
"recipes": "Recetas",
- "keywords": "Keywords"
+ "keywords": "Palabras clave"
},
"homebox": {
- "items": "Items",
+ "items": "Objetos",
"totalWithWarranty": "Con Garantía",
"locations": "Ubicaciones",
"labels": "Etiquetas",
@@ -875,6 +875,18 @@
},
"crowdsec": {
"alerts": "Alertas",
- "bans": "Bans"
+ "bans": "Baneos"
+ },
+ "wgeasy": {
+ "connected": "Conectado",
+ "enabled": "Activado",
+ "disabled": "Desactivado",
+ "total": "Total"
+ },
+ "swagdashboard": {
+ "proxied": "Proxied",
+ "auth": "With Auth",
+ "outdated": "Outdated",
+ "banned": "Banned"
}
}
diff --git a/public/locales/eu/common.json b/public/locales/eu/common.json
index 6625148c0..a4aba2036 100644
--- a/public/locales/eu/common.json
+++ b/public/locales/eu/common.json
@@ -876,5 +876,17 @@
"crowdsec": {
"alerts": "Alerts",
"bans": "Bans"
+ },
+ "wgeasy": {
+ "connected": "Connected",
+ "enabled": "Enabled",
+ "disabled": "Disabled",
+ "total": "Guztira"
+ },
+ "swagdashboard": {
+ "proxied": "Proxied",
+ "auth": "With Auth",
+ "outdated": "Outdated",
+ "banned": "Banned"
}
}
diff --git a/public/locales/fi/common.json b/public/locales/fi/common.json
index b775e9703..09639a20c 100644
--- a/public/locales/fi/common.json
+++ b/public/locales/fi/common.json
@@ -876,5 +876,17 @@
"crowdsec": {
"alerts": "Alerts",
"bans": "Bans"
+ },
+ "wgeasy": {
+ "connected": "Connected",
+ "enabled": "Käytössä",
+ "disabled": "Poissa käytöstä",
+ "total": "Yhteensä"
+ },
+ "swagdashboard": {
+ "proxied": "Proxied",
+ "auth": "With Auth",
+ "outdated": "Outdated",
+ "banned": "Banned"
}
}
diff --git a/public/locales/fr/common.json b/public/locales/fr/common.json
index d5a95638b..beb8420c6 100644
--- a/public/locales/fr/common.json
+++ b/public/locales/fr/common.json
@@ -876,5 +876,17 @@
"crowdsec": {
"alerts": "Alertes",
"bans": "Exclusions"
+ },
+ "wgeasy": {
+ "connected": "Connecté",
+ "enabled": "Activé",
+ "disabled": "Désactivé",
+ "total": "Total"
+ },
+ "swagdashboard": {
+ "proxied": "Par proxy",
+ "auth": "Avec authentification",
+ "outdated": "Obsolète",
+ "banned": "Banni"
}
}
diff --git a/public/locales/he/common.json b/public/locales/he/common.json
index a420823ed..fa310603c 100644
--- a/public/locales/he/common.json
+++ b/public/locales/he/common.json
@@ -876,5 +876,17 @@
"crowdsec": {
"alerts": "Alerts",
"bans": "Bans"
+ },
+ "wgeasy": {
+ "connected": "Connected",
+ "enabled": "מופעל",
+ "disabled": "מבוטל",
+ "total": "סה\"כ"
+ },
+ "swagdashboard": {
+ "proxied": "Proxied",
+ "auth": "With Auth",
+ "outdated": "Outdated",
+ "banned": "Banned"
}
}
diff --git a/public/locales/hi/common.json b/public/locales/hi/common.json
index 866a1280e..745ed8b4f 100644
--- a/public/locales/hi/common.json
+++ b/public/locales/hi/common.json
@@ -876,5 +876,17 @@
"crowdsec": {
"alerts": "Alerts",
"bans": "Bans"
+ },
+ "wgeasy": {
+ "connected": "Connected",
+ "enabled": "Enabled",
+ "disabled": "Disabled",
+ "total": "Total"
+ },
+ "swagdashboard": {
+ "proxied": "Proxied",
+ "auth": "With Auth",
+ "outdated": "Outdated",
+ "banned": "Banned"
}
}
diff --git a/public/locales/hr/common.json b/public/locales/hr/common.json
index 4b323b402..6ffef12f7 100644
--- a/public/locales/hr/common.json
+++ b/public/locales/hr/common.json
@@ -140,7 +140,7 @@
"connectionStatusPendingDisconnect": "Odspajanje u tijeku",
"connectionStatusDisconnecting": "Odspajanje",
"connectionStatusDisconnected": "Odspojeno",
- "connectionStatusConnected": "Connected",
+ "connectionStatusConnected": "Povezano",
"uptime": "Vrijeme rada",
"maxDown": "Maksimum preuzimanja",
"maxUp": "Maksimum prijenosa",
@@ -279,9 +279,9 @@
},
"netalertx": {
"total": "Ukupno",
- "connected": "Connected",
- "new_devices": "New Devices",
- "down_alerts": "Down Alerts"
+ "connected": "Povezano",
+ "new_devices": "Novi uređaji",
+ "down_alerts": "Obavijesti o nedostupnosti"
},
"pihole": {
"queries": "Upiti",
@@ -834,47 +834,59 @@
"criticals": "Kritično"
},
"plantit": {
- "events": "Events",
- "plants": "Plants",
+ "events": "Događaji",
+ "plants": "Biljke",
"photos": "Fotografije",
- "species": "Species"
+ "species": "Vrste"
},
"gitea": {
- "notifications": "Notifications",
+ "notifications": "Obavijesti",
"issues": "Problemi",
- "pulls": "Pull Requests"
+ "pulls": "Zahtjevi za povlačenje"
},
"stash": {
- "scenes": "Scenes",
- "scenesPlayed": "Scenes Played",
- "playCount": "Total Plays",
- "playDuration": "Time Watched",
- "sceneSize": "Scenes Size",
- "sceneDuration": "Scenes Duration",
- "images": "Images",
- "imageSize": "Images Size",
- "galleries": "Galleries",
- "performers": "Performers",
- "studios": "Studios",
+ "scenes": "Scene",
+ "scenesPlayed": "Reproducirane scene",
+ "playCount": "Ukupni broj reprodukcija",
+ "playDuration": "Vrijeme gledanja",
+ "sceneSize": "Veličina scene",
+ "sceneDuration": "Trajanje scene",
+ "images": "Slike",
+ "imageSize": "Veličina slike",
+ "galleries": "Galerije",
+ "performers": "Glumci",
+ "studios": "Studiji",
"movies": "Filmovi",
"tags": "Oznake",
- "oCount": "O Count"
+ "oCount": "O zbroj"
},
"tandoor": {
"users": "Korisnici",
"recipes": "Recepti",
- "keywords": "Keywords"
+ "keywords": "Ključne riječi"
},
"homebox": {
- "items": "Items",
- "totalWithWarranty": "With Warranty",
- "locations": "Locations",
- "labels": "Labels",
+ "items": "Stavke",
+ "totalWithWarranty": "S garancijom",
+ "locations": "Lokacije",
+ "labels": "Oznake",
"users": "Korisnici",
- "totalValue": "Total Value"
+ "totalValue": "Svukupno"
},
"crowdsec": {
"alerts": "Upozorenja",
- "bans": "Bans"
+ "bans": "Zabrane"
+ },
+ "wgeasy": {
+ "connected": "Povezano",
+ "enabled": "Aktivirano",
+ "disabled": "Deaktivirano",
+ "total": "Ukupno"
+ },
+ "swagdashboard": {
+ "proxied": "Posredovano",
+ "auth": "S autentifikacijom",
+ "outdated": "Zastarjelo",
+ "banned": "Zabranjen pristup"
}
}
diff --git a/public/locales/hu/common.json b/public/locales/hu/common.json
index 735de467d..aed09199d 100644
--- a/public/locales/hu/common.json
+++ b/public/locales/hu/common.json
@@ -45,7 +45,7 @@
"free": "Szabad",
"used": "Használt",
"load": "Terhelés",
- "temp": "HŐ",
+ "temp": "HŐM",
"max": "Max",
"uptime": "FUT"
},
@@ -140,7 +140,7 @@
"connectionStatusPendingDisconnect": "Szétkapcsolás függőben",
"connectionStatusDisconnecting": "Kapcsolat bontása",
"connectionStatusDisconnected": "Kapcsolat bontva",
- "connectionStatusConnected": "Connected",
+ "connectionStatusConnected": "Csatlakozva",
"uptime": "Üzemidő",
"maxDown": "Max let.",
"maxUp": "Max felt.",
@@ -279,9 +279,9 @@
},
"netalertx": {
"total": "Összes",
- "connected": "Connected",
- "new_devices": "New Devices",
- "down_alerts": "Down Alerts"
+ "connected": "Csatlakozva",
+ "new_devices": "Új eszközök",
+ "down_alerts": "Leállási riasztások"
},
"pihole": {
"queries": "Lekérdezések",
@@ -404,7 +404,7 @@
"cpu": "Processzor",
"load": "Terhelés",
"wait": "Kérjük várjon",
- "temp": "HŐ",
+ "temp": "HŐM",
"_temp": "Hőmérséklet",
"warn": "Figyelmeztet",
"uptime": "FUT",
@@ -876,5 +876,17 @@
"crowdsec": {
"alerts": "Riasztások",
"bans": "Bans"
+ },
+ "wgeasy": {
+ "connected": "Csatlakozva",
+ "enabled": "Bekapcsolva",
+ "disabled": "Kikapcsolva",
+ "total": "Összes"
+ },
+ "swagdashboard": {
+ "proxied": "Proxied",
+ "auth": "With Auth",
+ "outdated": "Outdated",
+ "banned": "Banned"
}
}
diff --git a/public/locales/id/common.json b/public/locales/id/common.json
index c1ca4450e..9c7a0ec8f 100644
--- a/public/locales/id/common.json
+++ b/public/locales/id/common.json
@@ -876,5 +876,17 @@
"crowdsec": {
"alerts": "Peringatan",
"bans": "Bans"
+ },
+ "wgeasy": {
+ "connected": "Connected",
+ "enabled": "Aktif",
+ "disabled": "Nonaktif",
+ "total": "Total"
+ },
+ "swagdashboard": {
+ "proxied": "Proxied",
+ "auth": "With Auth",
+ "outdated": "Outdated",
+ "banned": "Banned"
}
}
diff --git a/public/locales/it/common.json b/public/locales/it/common.json
index 8f583e665..1c4115f7f 100644
--- a/public/locales/it/common.json
+++ b/public/locales/it/common.json
@@ -876,5 +876,17 @@
"crowdsec": {
"alerts": "Allarmi",
"bans": "Bans"
+ },
+ "wgeasy": {
+ "connected": "Connesso",
+ "enabled": "Abilitato",
+ "disabled": "Disabilitati",
+ "total": "Totale"
+ },
+ "swagdashboard": {
+ "proxied": "Proxied",
+ "auth": "With Auth",
+ "outdated": "Outdated",
+ "banned": "Banned"
}
}
diff --git a/public/locales/ja/common.json b/public/locales/ja/common.json
index e2f6a57bf..80bb4506f 100644
--- a/public/locales/ja/common.json
+++ b/public/locales/ja/common.json
@@ -47,7 +47,7 @@
"load": "ロード",
"temp": "温度",
"max": "最大",
- "uptime": "上へ"
+ "uptime": "UP"
},
"unifi": {
"users": "ユーザ",
@@ -61,7 +61,7 @@
"wlan_devices": "WLAN デバイス",
"lan_users": "LAN ユーザ",
"wlan_users": "WLAN ユーザ",
- "up": "上へ",
+ "up": "UP",
"down": "下へ",
"wait": "お待ちください",
"empty_data": "サブシステムの状態は不明"
@@ -86,7 +86,7 @@
"error": "エラー",
"ping": "Ping",
"down": "下へ",
- "up": "上へ",
+ "up": "稼働",
"not_available": "利用できません。"
},
"siteMonitor": {
@@ -94,7 +94,7 @@
"error": "エラー",
"response": "応答",
"down": "下へ",
- "up": "上へ",
+ "up": "稼働",
"not_available": "利用できません。"
},
"emby": {
@@ -140,12 +140,12 @@
"connectionStatusPendingDisconnect": "接続を切断する",
"connectionStatusDisconnecting": "接続を切断中",
"connectionStatusDisconnected": "切断されました",
- "connectionStatusConnected": "Connected",
+ "connectionStatusConnected": "接続済",
"uptime": "稼働時間",
"maxDown": "最大ダウン",
"maxUp": "最大アップ",
"down": "下へ",
- "up": "上へ",
+ "up": "稼働",
"received": "受信済み",
"sent": "送信済み",
"externalIPAddress": "退出ID"
@@ -279,9 +279,9 @@
},
"netalertx": {
"total": "合計",
- "connected": "Connected",
- "new_devices": "New Devices",
- "down_alerts": "Down Alerts"
+ "connected": "接続済",
+ "new_devices": "新規デバイス",
+ "down_alerts": "ダウンアラート"
},
"pihole": {
"queries": "クエリ",
@@ -407,7 +407,7 @@
"temp": "温度",
"_temp": "温度",
"warn": "警告",
- "uptime": "上へ",
+ "uptime": "UP",
"total": "合計",
"free": "空き",
"used": "使用",
@@ -494,13 +494,13 @@
"up_to_date": "最新",
"child_bridges": "子ブリッジ",
"child_bridges_status": "{{ok}}/{{total}}",
- "up": "上へ",
+ "up": "稼働",
"pending": "保留中",
"down": "下へ"
},
"healthchecks": {
"new": "新着",
- "up": "上へ",
+ "up": "稼働",
"grace": "猶予期間中",
"down": "下へ",
"paused": "一時停止中",
@@ -617,7 +617,7 @@
"load": "読み込み平均",
"memory": "メモリ使用量",
"wanStatus": "WANステータス",
- "up": "上へ",
+ "up": "稼働",
"down": "下へ",
"temp": "温度",
"disk": "ディスク使用量",
@@ -799,7 +799,7 @@
"openwrt": {
"uptime": "稼働時間",
"cpuLoad": "CPU 平均負荷(5 分)",
- "up": "上へ",
+ "up": "稼働",
"down": "下へ",
"bytesTx": "送信済み",
"bytesRx": "受信済み"
@@ -813,7 +813,7 @@
"sitesDown": "サイトDown",
"paused": "一時停止中",
"notyetchecked": "チェックされていません",
- "up": "上へ",
+ "up": "稼働",
"seemsdown": "ダウンしているようです",
"down": "下へ",
"unknown": "不明"
@@ -875,6 +875,18 @@
},
"crowdsec": {
"alerts": "アラート",
- "bans": "Bans"
+ "bans": "禁止"
+ },
+ "wgeasy": {
+ "connected": "接続済",
+ "enabled": "有効",
+ "disabled": "無効",
+ "total": "合計"
+ },
+ "swagdashboard": {
+ "proxied": "Proxied",
+ "auth": "With Auth",
+ "outdated": "Outdated",
+ "banned": "Banned"
}
}
diff --git a/public/locales/ko/common.json b/public/locales/ko/common.json
index 5e7a90e11..342d1e37c 100644
--- a/public/locales/ko/common.json
+++ b/public/locales/ko/common.json
@@ -876,5 +876,17 @@
"crowdsec": {
"alerts": "경고",
"bans": "Bans"
+ },
+ "wgeasy": {
+ "connected": "Connected",
+ "enabled": "활성",
+ "disabled": "비활성",
+ "total": "총합"
+ },
+ "swagdashboard": {
+ "proxied": "Proxied",
+ "auth": "With Auth",
+ "outdated": "Outdated",
+ "banned": "Banned"
}
}
diff --git a/public/locales/lv/common.json b/public/locales/lv/common.json
index 1a46c862b..e9b8b20a9 100644
--- a/public/locales/lv/common.json
+++ b/public/locales/lv/common.json
@@ -876,5 +876,17 @@
"crowdsec": {
"alerts": "Paziņojumi",
"bans": "Bans"
+ },
+ "wgeasy": {
+ "connected": "Connected",
+ "enabled": "Enabled",
+ "disabled": "Disabled",
+ "total": "Kopā"
+ },
+ "swagdashboard": {
+ "proxied": "Proxied",
+ "auth": "With Auth",
+ "outdated": "Outdated",
+ "banned": "Banned"
}
}
diff --git a/public/locales/ms/common.json b/public/locales/ms/common.json
index f95831481..c05b70796 100644
--- a/public/locales/ms/common.json
+++ b/public/locales/ms/common.json
@@ -876,5 +876,17 @@
"crowdsec": {
"alerts": "Alerts",
"bans": "Bans"
+ },
+ "wgeasy": {
+ "connected": "Connected",
+ "enabled": "Didayakan",
+ "disabled": "Dinyahdayakan",
+ "total": "Jumlah"
+ },
+ "swagdashboard": {
+ "proxied": "Proxied",
+ "auth": "With Auth",
+ "outdated": "Outdated",
+ "banned": "Banned"
}
}
diff --git a/public/locales/nl/common.json b/public/locales/nl/common.json
index 8aff253eb..6910c07ad 100644
--- a/public/locales/nl/common.json
+++ b/public/locales/nl/common.json
@@ -876,5 +876,17 @@
"crowdsec": {
"alerts": "Meldingen",
"bans": "Bans"
+ },
+ "wgeasy": {
+ "connected": "Verbonden",
+ "enabled": "Ingeschakeld",
+ "disabled": "Uitgeschakeld",
+ "total": "Totaal"
+ },
+ "swagdashboard": {
+ "proxied": "Proxied",
+ "auth": "With Auth",
+ "outdated": "Outdated",
+ "banned": "Banned"
}
}
diff --git a/public/locales/no/common.json b/public/locales/no/common.json
index a0988c888..74f97249d 100644
--- a/public/locales/no/common.json
+++ b/public/locales/no/common.json
@@ -876,5 +876,17 @@
"crowdsec": {
"alerts": "Varsler",
"bans": "Utestengelse"
+ },
+ "wgeasy": {
+ "connected": "Tilkoblet",
+ "enabled": "Aktivert",
+ "disabled": "Deaktivert",
+ "total": "Totalt"
+ },
+ "swagdashboard": {
+ "proxied": "Proxied",
+ "auth": "With Auth",
+ "outdated": "Outdated",
+ "banned": "Banned"
}
}
diff --git a/public/locales/pl/common.json b/public/locales/pl/common.json
index 5c64296ea..eddd0a5a7 100644
--- a/public/locales/pl/common.json
+++ b/public/locales/pl/common.json
@@ -876,5 +876,17 @@
"crowdsec": {
"alerts": "Alarmy",
"bans": "Bany"
+ },
+ "wgeasy": {
+ "connected": "Connected",
+ "enabled": "Włączone",
+ "disabled": "Wyłączone",
+ "total": "Całkowite"
+ },
+ "swagdashboard": {
+ "proxied": "Proxied",
+ "auth": "With Auth",
+ "outdated": "Outdated",
+ "banned": "Banned"
}
}
diff --git a/public/locales/pt/common.json b/public/locales/pt/common.json
index 74b67f82e..558e98677 100644
--- a/public/locales/pt/common.json
+++ b/public/locales/pt/common.json
@@ -876,5 +876,17 @@
"crowdsec": {
"alerts": "Alertas",
"bans": "Bans"
+ },
+ "wgeasy": {
+ "connected": "Connected",
+ "enabled": "Ativo",
+ "disabled": "Desabilitado",
+ "total": "Total"
+ },
+ "swagdashboard": {
+ "proxied": "Proxied",
+ "auth": "With Auth",
+ "outdated": "Outdated",
+ "banned": "Banned"
}
}
diff --git a/public/locales/pt_BR/common.json b/public/locales/pt_BR/common.json
index f3b716bdb..e622ddebb 100644
--- a/public/locales/pt_BR/common.json
+++ b/public/locales/pt_BR/common.json
@@ -143,7 +143,7 @@
"connectionStatusConnected": "Conectado",
"uptime": "Ligado",
"maxDown": "Max. Down",
- "maxUp": "Max. Up",
+ "maxUp": "Máx. Acima",
"down": "Inativo",
"up": "Ativo",
"received": "Recebido",
@@ -876,5 +876,17 @@
"crowdsec": {
"alerts": "Alertas",
"bans": "Banimentos"
+ },
+ "wgeasy": {
+ "connected": "Conectado",
+ "enabled": "Ativo",
+ "disabled": "Desabilitado",
+ "total": "Total"
+ },
+ "swagdashboard": {
+ "proxied": "Proxied",
+ "auth": "With Auth",
+ "outdated": "Outdated",
+ "banned": "Banned"
}
}
diff --git a/public/locales/ro/common.json b/public/locales/ro/common.json
index 512904ff4..5b5187d36 100644
--- a/public/locales/ro/common.json
+++ b/public/locales/ro/common.json
@@ -876,5 +876,17 @@
"crowdsec": {
"alerts": "Alerts",
"bans": "Bans"
+ },
+ "wgeasy": {
+ "connected": "Connected",
+ "enabled": "Activat",
+ "disabled": "Dezactivat",
+ "total": "Total"
+ },
+ "swagdashboard": {
+ "proxied": "Proxied",
+ "auth": "With Auth",
+ "outdated": "Outdated",
+ "banned": "Banned"
}
}
diff --git a/public/locales/ru/common.json b/public/locales/ru/common.json
index 973c131f9..5c7c771a1 100644
--- a/public/locales/ru/common.json
+++ b/public/locales/ru/common.json
@@ -140,7 +140,7 @@
"connectionStatusPendingDisconnect": "Ожидает отключения",
"connectionStatusDisconnecting": "Отключение",
"connectionStatusDisconnected": "Отключено",
- "connectionStatusConnected": "Connected",
+ "connectionStatusConnected": "Подключено",
"uptime": "Время работы",
"maxDown": "Макс. Загрузка",
"maxUp": "Макс. Отдача",
@@ -279,9 +279,9 @@
},
"netalertx": {
"total": "Всего",
- "connected": "Connected",
- "new_devices": "New Devices",
- "down_alerts": "Down Alerts"
+ "connected": "Подключено",
+ "new_devices": "Новое устройство",
+ "down_alerts": "Оповещение о недоступности"
},
"pihole": {
"queries": "Запросы",
@@ -875,6 +875,18 @@
},
"crowdsec": {
"alerts": "Предупреждения",
- "bans": "Bans"
+ "bans": "Запреты"
+ },
+ "wgeasy": {
+ "connected": "Подключено",
+ "enabled": "Включено",
+ "disabled": "Выключено",
+ "total": "Всего"
+ },
+ "swagdashboard": {
+ "proxied": "Proxied",
+ "auth": "With Auth",
+ "outdated": "Outdated",
+ "banned": "Banned"
}
}
diff --git a/public/locales/sk/common.json b/public/locales/sk/common.json
index b792a4258..42afe41ab 100644
--- a/public/locales/sk/common.json
+++ b/public/locales/sk/common.json
@@ -140,7 +140,7 @@
"connectionStatusPendingDisconnect": "Čakám na odpojenie",
"connectionStatusDisconnecting": "Odpájanie",
"connectionStatusDisconnected": "Odpojené",
- "connectionStatusConnected": "Connected",
+ "connectionStatusConnected": "Pripojené",
"uptime": "Prevádzka",
"maxDown": "Max. sťahovanie",
"maxUp": "Max. nahrávanie",
@@ -279,9 +279,9 @@
},
"netalertx": {
"total": "Celkovo",
- "connected": "Connected",
- "new_devices": "New Devices",
- "down_alerts": "Down Alerts"
+ "connected": "Pripojené",
+ "new_devices": "Nové zariadenia",
+ "down_alerts": "Upozornenia o výpadkoch"
},
"pihole": {
"queries": "Dopyty",
@@ -846,7 +846,7 @@
},
"stash": {
"scenes": "Scény",
- "scenesPlayed": "Scenes Played",
+ "scenesPlayed": "Prehrané scény",
"playCount": "Celkovo prehraní",
"playDuration": "Pozeraný čas",
"sceneSize": "Veľkosť obrazovky",
@@ -869,12 +869,24 @@
"items": "Položky",
"totalWithWarranty": "So zárukou",
"locations": "Umiestnenia",
- "labels": "Labels",
+ "labels": "Štítky",
"users": "Používatelia",
- "totalValue": "Total Value"
+ "totalValue": "Celková hodnota"
},
"crowdsec": {
"alerts": "Upozornenia",
- "bans": "Bans"
+ "bans": "Bany"
+ },
+ "wgeasy": {
+ "connected": "Pripojené",
+ "enabled": "Povolené",
+ "disabled": "Zakázané",
+ "total": "Celkovo"
+ },
+ "swagdashboard": {
+ "proxied": "Proxied",
+ "auth": "With Auth",
+ "outdated": "Zastarané",
+ "banned": "Zabanovaný"
}
}
diff --git a/public/locales/sl/common.json b/public/locales/sl/common.json
index 83691aab1..6dcd5415c 100644
--- a/public/locales/sl/common.json
+++ b/public/locales/sl/common.json
@@ -153,7 +153,7 @@
"caddy": {
"upstreams": "Pretok gor",
"requests": "Trenutnih zahtev",
- "requests_failed": "Neuspešnih zahtev"
+ "requests_failed": "Neuspeš. zahtev"
},
"changedetectionio": {
"totalObserved": "Skupaj opazovano",
@@ -355,8 +355,8 @@
"enableIndexers": "Indekserji",
"numberOfGrabs": "Zajemi",
"numberOfQueries": "Poizvedbe",
- "numberOfFailGrabs": "Neuspešni zajemi",
- "numberOfFailQueries": "Neuspešne poizvedbe"
+ "numberOfFailGrabs": "Neuspeš. zajem",
+ "numberOfFailQueries": "Neuspeš. poizvedb"
},
"jackett": {
"configured": "Nastavljeno",
@@ -876,5 +876,17 @@
"crowdsec": {
"alerts": "Opozorila",
"bans": "Prepovedi"
+ },
+ "wgeasy": {
+ "connected": "Povezan",
+ "enabled": "Omogočen",
+ "disabled": "Onemogočen",
+ "total": "Skupaj"
+ },
+ "swagdashboard": {
+ "proxied": "Čez proxi",
+ "auth": "Z Auth",
+ "outdated": "Zastarelo",
+ "banned": "Prepovedan"
}
}
diff --git a/public/locales/sr/common.json b/public/locales/sr/common.json
index 71ca98dbd..627140001 100644
--- a/public/locales/sr/common.json
+++ b/public/locales/sr/common.json
@@ -876,5 +876,17 @@
"crowdsec": {
"alerts": "Alerts",
"bans": "Bans"
+ },
+ "wgeasy": {
+ "connected": "Connected",
+ "enabled": "Enabled",
+ "disabled": "Disabled",
+ "total": "Total"
+ },
+ "swagdashboard": {
+ "proxied": "Proxied",
+ "auth": "With Auth",
+ "outdated": "Outdated",
+ "banned": "Banned"
}
}
diff --git a/public/locales/sv/common.json b/public/locales/sv/common.json
index 7fc244908..53fe576cf 100644
--- a/public/locales/sv/common.json
+++ b/public/locales/sv/common.json
@@ -876,5 +876,17 @@
"crowdsec": {
"alerts": "Alerts",
"bans": "Bans"
+ },
+ "wgeasy": {
+ "connected": "Connected",
+ "enabled": "Aktiverad",
+ "disabled": "Inaktiverad",
+ "total": "Total"
+ },
+ "swagdashboard": {
+ "proxied": "Proxied",
+ "auth": "With Auth",
+ "outdated": "Outdated",
+ "banned": "Banned"
}
}
diff --git a/public/locales/te/common.json b/public/locales/te/common.json
index 40bd9f7ab..1dd640f29 100644
--- a/public/locales/te/common.json
+++ b/public/locales/te/common.json
@@ -876,5 +876,17 @@
"crowdsec": {
"alerts": "Alerts",
"bans": "Bans"
+ },
+ "wgeasy": {
+ "connected": "Connected",
+ "enabled": "ప్రారంభించబడింది",
+ "disabled": "డిసేబ్లెడ్",
+ "total": "మొత్తం"
+ },
+ "swagdashboard": {
+ "proxied": "Proxied",
+ "auth": "With Auth",
+ "outdated": "Outdated",
+ "banned": "Banned"
}
}
diff --git a/public/locales/th/common.json b/public/locales/th/common.json
index 9bb8ee9b3..682451b45 100644
--- a/public/locales/th/common.json
+++ b/public/locales/th/common.json
@@ -876,5 +876,17 @@
"crowdsec": {
"alerts": "Alerts",
"bans": "Bans"
+ },
+ "wgeasy": {
+ "connected": "Connected",
+ "enabled": "Enabled",
+ "disabled": "Disabled",
+ "total": "ทั้งหมด"
+ },
+ "swagdashboard": {
+ "proxied": "Proxied",
+ "auth": "With Auth",
+ "outdated": "Outdated",
+ "banned": "Banned"
}
}
diff --git a/public/locales/tr/common.json b/public/locales/tr/common.json
index 10e32a0c9..a44ec8f06 100644
--- a/public/locales/tr/common.json
+++ b/public/locales/tr/common.json
@@ -876,5 +876,17 @@
"crowdsec": {
"alerts": "Alarmlar",
"bans": "Yasaklar"
+ },
+ "wgeasy": {
+ "connected": "Bağlandı",
+ "enabled": "Etkin",
+ "disabled": "Devre Dışı",
+ "total": "Toplam"
+ },
+ "swagdashboard": {
+ "proxied": "Proxied",
+ "auth": "With Auth",
+ "outdated": "Outdated",
+ "banned": "Banned"
}
}
diff --git a/public/locales/uk/common.json b/public/locales/uk/common.json
index 55e8c07ea..239de674a 100644
--- a/public/locales/uk/common.json
+++ b/public/locales/uk/common.json
@@ -876,5 +876,17 @@
"crowdsec": {
"alerts": "Оповіщення",
"bans": "Bans"
+ },
+ "wgeasy": {
+ "connected": "Connected",
+ "enabled": "Увімкнено",
+ "disabled": "Вимкнено",
+ "total": "Усього"
+ },
+ "swagdashboard": {
+ "proxied": "Proxied",
+ "auth": "With Auth",
+ "outdated": "Outdated",
+ "banned": "Banned"
}
}
diff --git a/public/locales/vi/common.json b/public/locales/vi/common.json
index 5299c54dc..7eeab1134 100644
--- a/public/locales/vi/common.json
+++ b/public/locales/vi/common.json
@@ -876,5 +876,17 @@
"crowdsec": {
"alerts": "Alerts",
"bans": "Bans"
+ },
+ "wgeasy": {
+ "connected": "Connected",
+ "enabled": "Enabled",
+ "disabled": "Disabled",
+ "total": "Tổng"
+ },
+ "swagdashboard": {
+ "proxied": "Proxied",
+ "auth": "With Auth",
+ "outdated": "Outdated",
+ "banned": "Banned"
}
}
diff --git a/public/locales/yue/common.json b/public/locales/yue/common.json
index d7a9242c2..4d425c454 100644
--- a/public/locales/yue/common.json
+++ b/public/locales/yue/common.json
@@ -876,5 +876,17 @@
"crowdsec": {
"alerts": "警示",
"bans": "禁止"
+ },
+ "wgeasy": {
+ "connected": "Connected",
+ "enabled": "啟用",
+ "disabled": "停用咗",
+ "total": "全部"
+ },
+ "swagdashboard": {
+ "proxied": "Proxied",
+ "auth": "With Auth",
+ "outdated": "Outdated",
+ "banned": "Banned"
}
}
diff --git a/public/locales/zh-Hans/common.json b/public/locales/zh-Hans/common.json
index 41706e9f1..f82495b91 100644
--- a/public/locales/zh-Hans/common.json
+++ b/public/locales/zh-Hans/common.json
@@ -54,10 +54,10 @@
"uptime": "运行时间",
"days": "天",
"wan": "WAN",
- "lan": "局域网",
- "wlan": "无线局域网",
+ "lan": "LAN",
+ "wlan": "WLAN",
"devices": "设备",
- "lan_devices": "有线设备",
+ "lan_devices": "LAN 设备",
"wlan_devices": "WLAN 设备",
"lan_users": "有线用户",
"wlan_users": "无线用户",
@@ -146,7 +146,7 @@
"maxUp": "",
"down": "离线",
"up": "在线",
- "received": "最大上传数",
+ "received": "已接收",
"sent": "已发送",
"externalIPAddress": "外部IP"
},
@@ -234,7 +234,7 @@
},
"sonarr": {
"wanted": "关注中",
- "queued": "已加入队列",
+ "queued": "队列中",
"series": "剧集",
"queue": "队列",
"unknown": "未知"
@@ -242,19 +242,19 @@
"radarr": {
"wanted": "关注中",
"missing": "缺失",
- "queued": "已加入队列",
+ "queued": "队列中",
"movies": "电影",
"queue": "队列",
"unknown": "未知"
},
"lidarr": {
"wanted": "关注中",
- "queued": "已加入队列",
+ "queued": "队列中",
"artists": "艺术家"
},
"readarr": {
"wanted": "关注中",
- "queued": "已加入队列",
+ "queued": "队列中",
"books": "书籍"
},
"bazarr": {
@@ -375,7 +375,7 @@
},
"medusa": {
"wanted": "关注中",
- "queued": "已加入队列",
+ "queued": "队列中",
"series": "剧集"
},
"minecraft": {
@@ -802,7 +802,7 @@
"up": "在线",
"down": "离线",
"bytesTx": "已传输",
- "bytesRx": "最大上传数"
+ "bytesRx": "已接收"
},
"uptimerobot": {
"status": "状态",
@@ -876,5 +876,17 @@
"crowdsec": {
"alerts": "警告",
"bans": "禁用"
+ },
+ "wgeasy": {
+ "connected": "已连接",
+ "enabled": "启用",
+ "disabled": "禁用",
+ "total": "总计"
+ },
+ "swagdashboard": {
+ "proxied": "已代理",
+ "auth": "使用认证",
+ "outdated": "已过期",
+ "banned": "已禁止"
}
}
diff --git a/public/locales/zh-Hant/common.json b/public/locales/zh-Hant/common.json
index 38b7ea427..e88ac2bbc 100644
--- a/public/locales/zh-Hant/common.json
+++ b/public/locales/zh-Hant/common.json
@@ -876,5 +876,17 @@
"crowdsec": {
"alerts": "警示",
"bans": "禁止"
+ },
+ "wgeasy": {
+ "connected": "Connected",
+ "enabled": "已啟用",
+ "disabled": "已停用",
+ "total": "全部"
+ },
+ "swagdashboard": {
+ "proxied": "Proxied",
+ "auth": "With Auth",
+ "outdated": "Outdated",
+ "banned": "Banned"
}
}
diff --git a/src/components/widgets/unifi_console/unifi_console.jsx b/src/components/widgets/unifi_console/unifi_console.jsx
index 0031b224b..5295dbb73 100644
--- a/src/components/widgets/unifi_console/unifi_console.jsx
+++ b/src/components/widgets/unifi_console/unifi_console.jsx
@@ -14,8 +14,8 @@ import useWidgetAPI from "utils/proxy/use-widget-api";
export default function Widget({ options }) {
const { t } = useTranslation();
- // eslint-disable-next-line no-param-reassign
- options.type = "unifi_console";
+ // eslint-disable-next-line no-param-reassign, no-multi-assign
+ options.service_group = options.service_name = "unifi_console";
const { data: statsData, error: statsError } = useWidgetAPI(options, "stat/sites", { index: options.index });
if (statsError) {
diff --git a/src/pages/api/widgets/openweathermap.js b/src/pages/api/widgets/openweathermap.js
index a20709975..089ee804e 100644
--- a/src/pages/api/widgets/openweathermap.js
+++ b/src/pages/api/widgets/openweathermap.js
@@ -1,9 +1,11 @@
import cachedFetch from "utils/proxy/cached-fetch";
import { getSettings } from "utils/config/config";
+import { getPrivateWidgetOptions } from "utils/config/widget-helpers";
export default async function handler(req, res) {
- const { latitude, longitude, units, provider, cache, lang } = req.query;
- let { apiKey } = req.query;
+ const { latitude, longitude, units, provider, cache, lang, index } = req.query;
+ const privateWidgetOptions = await getPrivateWidgetOptions("openweathermap", index);
+ let { apiKey } = privateWidgetOptions;
if (!apiKey && !provider) {
return res.status(400).json({ error: "Missing API key or provider" });
diff --git a/src/pages/api/widgets/weather.js b/src/pages/api/widgets/weather.js
index 5cba47ba7..9d0451ce9 100644
--- a/src/pages/api/widgets/weather.js
+++ b/src/pages/api/widgets/weather.js
@@ -1,9 +1,11 @@
import cachedFetch from "utils/proxy/cached-fetch";
import { getSettings } from "utils/config/config";
+import { getPrivateWidgetOptions } from "utils/config/widget-helpers";
export default async function handler(req, res) {
- const { latitude, longitude, provider, cache, lang } = req.query;
- let { apiKey } = req.query;
+ const { latitude, longitude, provider, cache, lang, index } = req.query;
+ const privateWidgetOptions = await getPrivateWidgetOptions("weatherapi", index);
+ let { apiKey } = privateWidgetOptions;
if (!apiKey && !provider) {
return res.status(400).json({ error: "Missing API key or provider" });
diff --git a/src/utils/config/service-helpers.js b/src/utils/config/service-helpers.js
index 8e2f12d54..7de077bff 100644
--- a/src/utils/config/service-helpers.js
+++ b/src/utils/config/service-helpers.js
@@ -254,7 +254,8 @@ export async function servicesFromKubernetes() {
ingress.metadata.annotations &&
ingress.metadata.annotations[`${ANNOTATION_BASE}/enabled`] === "true" &&
(!ingress.metadata.annotations[`${ANNOTATION_BASE}/instance`] ||
- ingress.metadata.annotations[`${ANNOTATION_BASE}/instance`] === instanceName),
+ ingress.metadata.annotations[`${ANNOTATION_BASE}/instance`] === instanceName ||
+ `${ANNOTATION_BASE}/instance.${instanceName}` in ingress.metadata.annotations),
)
.map((ingress) => {
let constructedService = {
diff --git a/src/utils/config/widget-helpers.js b/src/utils/config/widget-helpers.js
index 6514fea2c..7c5c78cd5 100644
--- a/src/utils/config/widget-helpers.js
+++ b/src/utils/config/widget-helpers.js
@@ -32,7 +32,7 @@ export async function cleanWidgetGroups(widgets) {
const optionKeys = Object.keys(sanitizedOptions);
// delete private options from the sanitized options
- ["username", "password", "key"].forEach((pO) => {
+ ["username", "password", "key", "apiKey"].forEach((pO) => {
if (optionKeys.includes(pO)) {
delete sanitizedOptions[pO];
}
@@ -57,7 +57,7 @@ export async function getPrivateWidgetOptions(type, widgetIndex) {
const widgets = await widgetsFromConfig();
const privateOptions = widgets.map((widget) => {
- const { index, url, username, password, key } = widget.options;
+ const { index, url, username, password, key, apiKey } = widget.options;
return {
type: widget.type,
@@ -67,6 +67,7 @@ export async function getPrivateWidgetOptions(type, widgetIndex) {
username,
password,
key,
+ apiKey,
},
};
});
diff --git a/src/utils/proxy/api-helpers.js b/src/utils/proxy/api-helpers.js
index c734a0979..8e0682dbc 100644
--- a/src/utils/proxy/api-helpers.js
+++ b/src/utils/proxy/api-helpers.js
@@ -10,7 +10,6 @@ export function formatApiCall(url, args) {
export function getURLSearchParams(widget, endpoint) {
const params = new URLSearchParams({
- type: widget.type,
group: widget.service_group,
service: widget.service_name,
});
@@ -53,6 +52,7 @@ export function sanitizeErrorURL(errorURL) {
const url = new URL(errorURL);
["apikey", "api_key", "token", "t", "access_token", "auth"].forEach((key) => {
if (url.searchParams.has(key)) url.searchParams.set(key, "***");
+ if (url.hash.includes(key)) url.hash = url.hash.replace(new RegExp(`${key}=[^&]+`), `${key}=***`);
});
return url.toString();
}
diff --git a/src/utils/proxy/handlers/jsonrpc.js b/src/utils/proxy/handlers/jsonrpc.js
index 4e79b76b0..b1b080fd0 100644
--- a/src/utils/proxy/handlers/jsonrpc.js
+++ b/src/utils/proxy/handlers/jsonrpc.js
@@ -31,6 +31,10 @@ export async function sendJsonRpcRequest(url, method, params, username, password
if (status === 200) {
const json = JSON.parse(data.toString());
+ if (json.id === null) {
+ json.id = 1;
+ }
+
// in order to get access to the underlying error object in the JSON response
// you must set `result` equal to undefined
if (json.error && json.result === null) {
diff --git a/src/widgets/caddy/component.jsx b/src/widgets/caddy/component.jsx
index adeca2371..36e5f959a 100644
--- a/src/widgets/caddy/component.jsx
+++ b/src/widgets/caddy/component.jsx
@@ -8,7 +8,7 @@ export default function Component({ service }) {
const { t } = useTranslation();
const { widget } = service;
- const { data: resultData, error: resultError } = useWidgetAPI(widget, "result");
+ const { data: resultData, error: resultError } = useWidgetAPI(widget, "upstreams");
if (resultError) {
return
;
diff --git a/src/widgets/caddy/widget.js b/src/widgets/caddy/widget.js
index 2fb1978bc..7e1dc6ba4 100644
--- a/src/widgets/caddy/widget.js
+++ b/src/widgets/caddy/widget.js
@@ -1,8 +1,14 @@
import genericProxyHandler from "utils/proxy/handlers/generic";
const widget = {
- api: "{url}/reverse_proxy/upstreams",
+ api: "{url}/{endpoint}",
proxyHandler: genericProxyHandler,
+
+ mappings: {
+ upstreams: {
+ endpoint: "reverse_proxy/upstreams",
+ },
+ },
};
export default widget;
diff --git a/src/widgets/coinmarketcap/component.jsx b/src/widgets/coinmarketcap/component.jsx
index c351cd8d7..7e717bef5 100644
--- a/src/widgets/coinmarketcap/component.jsx
+++ b/src/widgets/coinmarketcap/component.jsx
@@ -65,7 +65,7 @@ export default function Component({ service }) {
return (
-
+
diff --git a/src/widgets/emby/component.jsx b/src/widgets/emby/component.jsx
index 090a9c3f4..6f66d1dc4 100644
--- a/src/widgets/emby/component.jsx
+++ b/src/widgets/emby/component.jsx
@@ -225,7 +225,9 @@ export default function Component({ service }) {
}),
);
const url = `/api/services/proxy?${params.toString()}`;
- await fetch(url).then(() => {
+ await fetch(url, {
+ method: "POST",
+ }).then(() => {
sessionMutate();
});
}
diff --git a/src/widgets/glances/widget.js b/src/widgets/glances/widget.js
index e018ae39b..00d3ac5ad 100644
--- a/src/widgets/glances/widget.js
+++ b/src/widgets/glances/widget.js
@@ -3,7 +3,7 @@ import credentialedProxyHandler from "utils/proxy/handlers/credentialed";
const widget = {
api: "{url}/api/{endpoint}",
proxyHandler: credentialedProxyHandler,
- allowedEndpoints: /\d\/quicklook|diskio|fs|gpu|system|mem|network|processlist|sensors/,
+ allowedEndpoints: /\d\/quicklook|diskio|cpu|fs|gpu|system|mem|network|processlist|sensors/,
};
export default widget;
diff --git a/src/widgets/omada/component.jsx b/src/widgets/omada/component.jsx
index c4da60677..e63f93d36 100644
--- a/src/widgets/omada/component.jsx
+++ b/src/widgets/omada/component.jsx
@@ -9,7 +9,7 @@ export default function Component({ service }) {
const { widget } = service;
- const { data: omadaData, error: omadaAPIError } = useWidgetAPI(widget, {
+ const { data: omadaData, error: omadaAPIError } = useWidgetAPI(widget, "info", {
refreshInterval: 5000,
});
diff --git a/src/widgets/omada/widget.js b/src/widgets/omada/widget.js
index 5e32edad7..3f5a70a16 100644
--- a/src/widgets/omada/widget.js
+++ b/src/widgets/omada/widget.js
@@ -2,6 +2,12 @@ import omadaProxyHandler from "./proxy";
const widget = {
proxyHandler: omadaProxyHandler,
+
+ mappings: {
+ info: {
+ endpoint: "api/info",
+ },
+ },
};
export default widget;
diff --git a/src/widgets/openwrt/proxy.js b/src/widgets/openwrt/proxy.js
index 04c7a5039..977db8ca9 100644
--- a/src/widgets/openwrt/proxy.js
+++ b/src/widgets/openwrt/proxy.js
@@ -77,7 +77,7 @@ async function fetchSystem(url) {
const systemResponse = JSON.parse(data.toString())[1];
const response = {
uptime: systemResponse.uptime,
- cpuLoad: systemResponse.load[1],
+ cpuLoad: (systemResponse.load[1] / 65536.0).toFixed(2),
};
return [200, contentType, response];
}
diff --git a/src/widgets/stash/component.jsx b/src/widgets/stash/component.jsx
index 66f949c12..3d64c4902 100644
--- a/src/widgets/stash/component.jsx
+++ b/src/widgets/stash/component.jsx
@@ -1,18 +1,26 @@
import { useTranslation } from "next-i18next";
+import { useEffect, useState } from "react";
import Container from "components/services/widget/container";
import Block from "components/services/widget/block";
-import useWidgetAPI from "utils/proxy/use-widget-api";
+import { formatProxyUrl } from "utils/proxy/api-helpers";
export default function Component({ service }) {
const { t } = useTranslation();
const { widget } = service;
- const { data: stats, error: stashError } = useWidgetAPI(widget, "stats");
+ const [stats, setStats] = useState(null);
- if (stashError) {
- return
;
- }
+ useEffect(() => {
+ async function fetchStats() {
+ const url = formatProxyUrl(widget, "stats");
+ const res = await fetch(url, { method: "POST" });
+ setStats(await res.json());
+ }
+ if (!stats) {
+ fetchStats();
+ }
+ }, [widget, stats]);
if (!stats) {
return (
diff --git a/src/widgets/unifi/proxy.js b/src/widgets/unifi/proxy.js
index c8356c1bd..98c98f377 100644
--- a/src/widgets/unifi/proxy.js
+++ b/src/widgets/unifi/proxy.js
@@ -14,13 +14,13 @@ const prefixCacheKey = `${proxyName}__prefix`;
const logger = createLogger(proxyName);
async function getWidget(req) {
- const { group, service, type } = req.query;
+ const { group, service } = req.query;
let widget = null;
- if (type === "unifi_console") {
+ if (group === "unifi_console" && service === "unifi_console") {
// info widget
const index = req.query?.query ? JSON.parse(req.query.query).index : undefined;
- widget = await getPrivateWidgetOptions(type, index);
+ widget = await getPrivateWidgetOptions("unifi_console", index);
if (!widget) {
logger.debug("Error retrieving settings for this Unifi widget");
return null;
diff --git a/src/widgets/unmanic/component.jsx b/src/widgets/unmanic/component.jsx
index 03447068e..986884634 100644
--- a/src/widgets/unmanic/component.jsx
+++ b/src/widgets/unmanic/component.jsx
@@ -1,16 +1,30 @@
+import { useEffect, useState } from "react";
+
import Container from "components/services/widget/container";
import Block from "components/services/widget/block";
import useWidgetAPI from "utils/proxy/use-widget-api";
+import { formatProxyUrl } from "utils/proxy/api-helpers";
export default function Component({ service }) {
const { widget } = service;
const { data: workersData, error: workersError } = useWidgetAPI(widget, "workers");
- const { data: pendingData, error: pendingError } = useWidgetAPI(widget, "pending");
- if (workersError || pendingError) {
- const finalError = workersError ?? pendingError;
- return
;
+ const [pendingData, setPendingData] = useState(null);
+
+ useEffect(() => {
+ async function fetchPending() {
+ const url = formatProxyUrl(widget, "pending");
+ const res = await fetch(url, { method: "POST" });
+ setPendingData(await res.json());
+ }
+ if (!pendingData) {
+ fetchPending();
+ }
+ }, [widget, pendingData]);
+
+ if (workersError) {
+ return
;
}
if (!workersData || !pendingData) {
diff --git a/src/widgets/uptimerobot/component.jsx b/src/widgets/uptimerobot/component.jsx
index c0cb670f3..274854019 100644
--- a/src/widgets/uptimerobot/component.jsx
+++ b/src/widgets/uptimerobot/component.jsx
@@ -1,18 +1,26 @@
import { useTranslation } from "next-i18next";
+import { useEffect, useState } from "react";
import Container from "components/services/widget/container";
import Block from "components/services/widget/block";
-import useWidgetAPI from "utils/proxy/use-widget-api";
+import { formatProxyUrl } from "utils/proxy/api-helpers";
export default function Component({ service }) {
const { widget } = service;
const { t } = useTranslation();
- const { data: uptimerobotData, error: uptimerobotError } = useWidgetAPI(widget, "getmonitors");
+ const [uptimerobotData, setUptimerobotData] = useState(null);
- if (uptimerobotError) {
- return
;
- }
+ useEffect(() => {
+ async function fetchData() {
+ const url = formatProxyUrl(widget, "getmonitors");
+ const res = await fetch(url, { method: "POST" });
+ setUptimerobotData(await res.json());
+ }
+ if (!uptimerobotData) {
+ fetchData();
+ }
+ }, [widget, uptimerobotData]);
if (!uptimerobotData) {
return (
diff --git a/src/widgets/wgeasy/component.jsx b/src/widgets/wgeasy/component.jsx
index 0289d48c4..624002c4f 100644
--- a/src/widgets/wgeasy/component.jsx
+++ b/src/widgets/wgeasy/component.jsx
@@ -28,7 +28,7 @@ export default function Component({ service }) {
const enabled = infoData.filter((item) => item.enabled).length;
const disabled = infoData.length - enabled;
- const connectionThreshold = widget.threshold ?? 2 * 60 * 1000;
+ const connectionThreshold = (widget.threshold ?? 2) * 60 * 1000;
const currentTime = new Date();
const connected = infoData.filter(
(item) => currentTime - new Date(item.latestHandshakeAt) < connectionThreshold,
diff --git a/src/widgets/wgeasy/proxy.js b/src/widgets/wgeasy/proxy.js
index ec733475e..d4289dc66 100644
--- a/src/widgets/wgeasy/proxy.js
+++ b/src/widgets/wgeasy/proxy.js
@@ -21,14 +21,21 @@ async function login(widget, service) {
});
try {
- const connectSidCookie = responseHeaders["set-cookie"]
+ let connectSidCookie = responseHeaders["set-cookie"];
+ if (!connectSidCookie) {
+ const sid = cache.get(`${sessionSIDCacheKey}.${service}`);
+ if (sid) {
+ return sid;
+ }
+ }
+ connectSidCookie = connectSidCookie
.find((cookie) => cookie.startsWith("connect.sid="))
.split(";")[0]
.replace("connect.sid=", "");
cache.put(`${sessionSIDCacheKey}.${service}`, connectSidCookie);
return connectSidCookie;
} catch (e) {
- logger.error(`Error logging into wg-easy`);
+ logger.error(`Error logging into wg-easy, error: ${e}`);
cache.del(`${sessionSIDCacheKey}.${service}`);
return null;
}
diff --git a/src/pages/api/services/proxy.js b/src/pages/api/services/proxy.js
index 9347c4eb2..fd39ab96a 100644
--- a/src/pages/api/services/proxy.js
+++ b/src/pages/api/services/proxy.js
@@ -2,12 +2,21 @@ import { formatApiCall } from "utils/proxy/api-helpers";
import createLogger from "utils/logger";
import genericProxyHandler from "utils/proxy/handlers/generic";
import widgets from "widgets/widgets";
+import calendarProxyHandler from "widgets/calendar/proxy";
+import getServiceWidget from "utils/config/service-helpers";
const logger = createLogger("servicesProxy");
export default async function handler(req, res) {
try {
- const { type } = req.query;
+ const { service, group } = req.query;
+ const serviceWidget = await getServiceWidget(group, service);
+ let type = serviceWidget?.type;
+
+ // exceptions
+ if (type === "calendar") type = "ical";
+ else if (service === "unifi_console" && group === "unifi_console") type = "unifi_console";
+
const widget = widgets[type];
if (!widget) {
@@ -18,8 +27,8 @@ export default async function handler(req, res) {
const serviceProxyHandler = widget.proxyHandler || genericProxyHandler;
if (serviceProxyHandler instanceof Function) {
- // quick return for no endpoint services
- if (!req.query.endpoint) {
+ // quick return for no endpoint services, calendar is an exception
+ if (!req.query.endpoint || serviceProxyHandler === calendarProxyHandler) {
return serviceProxyHandler(req, res);
}
@@ -32,6 +41,11 @@ export default async function handler(req, res) {
const endpoint = mapping?.endpoint;
const endpointProxy = mapping?.proxyHandler || serviceProxyHandler;
+ if (mapping.method && mapping.method !== req.method) {
+ logger.debug("Unsupported method: %s", req.method);
+ return res.status(403).json({ error: "Unsupported method" });
+ }
+
if (!endpoint) {
logger.debug("Unsupported service endpoint: %s", type);
return res.status(403).json({ error: "Unsupported service endpoint" });
@@ -43,15 +57,17 @@ export default async function handler(req, res) {
if (req.query.segments) {
const segments = JSON.parse(req.query.segments);
- for (const key in segments) {
+ let validSegments = true;
+ Object.keys(segments).forEach((key) => {
if (!mapping.segments.includes(key)) {
logger.debug("Unsupported segment: %s", key);
- return res.status(403).json({ error: "Unsupported segment" });
- } else if (segments[key].includes("/")) {
+ validSegments = false;
+ } else if (segments[key].includes("/") || segments[key].includes("\\") || segments[key].includes("..")) {
logger.debug("Unsupported segment value: %s", segments[key]);
- return res.status(403).json({ error: "Unsupported segment value" });
+ validSegments = false;
}
- }
+ });
+ if (!validSegments) return res.status(403).json({ error: "Unsupported segment" });
req.query.endpoint = formatApiCall(endpoint, segments);
}